# Spatial transformers

```{eval-rst}
.. automodule:: deepali.spatial.transformer
    :noindex:
```

## Image transformer

```{eval-rst}
.. automodule:: deepali.spatial.ImageTransformer
    :noindex:
```

## Point set transformer

```{eval-rst}
.. automodule:: deepali.spatial.PointSetTransformer
    :noindex:
```
